@@ -53,8 +53,7 @@ class OntologyVerbaliser:
     r"""A rule-based natural language verbaliser for the OWL logical expressions, e.g., [`OWLAxiom`](http://owlcs.github.io/owlapi/apidocs_5/org/semanticweb/owlapi/model/OWLAxiom.html)
     and [`OWLClassExpression`](https://owlcs.github.io/owlapi/apidocs_4/org/semanticweb/owlapi/model/OWLClassExpression.html).
 
-    This is **not** a full-fledged ontology verbaliser and supports a limited set of patterns regarding
-    class expressions.
+    This is not a full-fledged ontology verbaliser but can already deal with most kinds of class expressions.
 
     Attributes:
         onto (Ontology): An ontology whose entities are to be verbalised.
@@ -77,10 +76,10 @@ class OntologyVerbaliser:
         self.vocab = {k: literal_or_iri(k, v) for k, v in self.vocab.items()}  # only set one name for each entity
 
     def update_entity_name(self, entity_iri: str, entity_name: str):
-        """Update the entity name dictionary.
+        """Update the name of an entity in `self.vocab`.
 
         If you want to change the name of a specific entity, you should call this
-        function before verbalisation.
+        function before applying verbalisation.
         """
         self.vocab[entity_iri] = entity_name
 
@@ -101,7 +100,7 @@ class OntologyVerbaliser:
         - merging restriction statements that have the **same object property**;
         - if **object property** that starts with an **adjective** or a **noun**, add **"it"** to the head;
         - the keyword **"only"** is inserted between the object property and the class expression for an **universal restriction** statement;
-        - the keyword **"some"** is inserted between the object property and the class expression for an *existential restriction** statement;
+        - the keyword **"some"** is inserted between the object property and the class expression for an **existential restriction** statement;
         - in a conjunction or disjunction statement, if there is **no atomic class**, then the keyword for the 
         anonymous class **"something"** is appended to the head.
 
@@ -211,18 +210,21 @@ class OntologyVerbaliser:
         for v in list(existential_restriction_children.values()) + list(universal_restriction_children.values()):
             # restriction = v[0].type
             if len(v) > 1:
-                merged_child = dict()
+                merged_child = CfgNode(dict())
                 merged_child.update(v[0])  # initialised with the first one
                 merged_child["class"] = CfgNode(
-                    {"verbal": v[0]["class"].verbal, "classes": [v[0]["class"]], "type": junction_node[:3]}
+                    {"verbal": v[0]["class"].verbal, "classes": [v[0]["class"]], "type": junction_node.name[:3]}
                 )
 
                 for i in range(1, len(v)):
-                    merged_child["class"].verbal += f" {junction_word} " + merged_child["class"].verbal
+                    # v 0.5.2 fix for len(v) > 1 case
+                    merged_child.verbal += f" {junction_word} " + v[i]["class"].verbal  # update grouped concepts with property
+                    merged_child["class"].verbal += f" {junction_word} " + v[i]["class"].verbal  # update grouped concepts
                     merged_child["class"].classes.append(v[i]["class"])
                 merged_children.append(merged_child)
-
-            merged_children.append(v[0])
+                # print(merged_children)
+            else:
+                merged_children.append(v[0])
 
         results = CfgNode(
             {
@@ -241,7 +243,12 @@ class OntologyVerbaliser:
         else:
             results.verbal += f" {junction_word} ".join(c.verbal for c in other_children)
             if merged_children:
-                results.verbal += " that " + f" {junction_word} ".join(c.verbal for c in merged_children)
+                if junction_word == "and":
+                    # sea food and non-vergetarian product that derives from shark and goldfish
+                    results.verbal += " that " + f" {junction_word} ".join(c.verbal for c in merged_children)
+                elif junction_word == "or":
+                    # sea food or non-vergetarian product or something that derives from shark or goldfish
+                    results.verbal += " or something that " + f" {junction_word} ".join(c.verbal for c in merged_children)
 
         return results
 
